@@ -1,5 +1,5 @@
 // -*- C++ -*-
-/* Copyright (C) 1989, 1990, 1991, 1992 Free Software Foundation, Inc.
+/* Copyright (C) 1989, 1990, 1991, 1992, 2002 Free Software Foundation, Inc.
      Written by James Clark (jjc@jclark.com)
 
 This file is part of groff.
@@ -54,6 +54,8 @@ public:
   const char *get_name();
   const char *get_internal_name();
 
+  static int scan_papersize(const char *, const char **, double *, double *);
+
   static font *load_font(const char *, int *not_found = 0);
   static void command_line_font_dir(const char *path);
   static FILE *open_file(const char *name, char **pathp);
@@ -69,6 +71,7 @@ public:
   static int unitwidth;
   static int paperwidth;
   static int paperlength;
+  static const char *papersize;
   static int biggestfont;
   static int spare2;
   static int sizescale;
@@ -107,6 +110,7 @@ private:
   void compact();
 
   static int scale(int w, int pointsize);
+  static int unit_scale(double *value, char unit);
   virtual void handle_unknown_font_command(const char *command,
 					   const char *arg,
 					   const char *file, int lineno);
