@@ -57,3 +57,7 @@ Foundation, 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA. */
 #ifndef O_RDONLY
 #define O_RDONLY 0
 #endif
+
+#ifndef HAVE_ISATTY
+#define isatty(n) (1)
+#endif
