@@ -1,5 +1,6 @@
 // -*- C++ -*- 
-/* Copyright (C) 1989, 1990, 1991, 1992 Free Software Foundation, Inc.
+/* Copyright (C) 1989, 1990, 1991, 1992, 2000, 2001
+   Free Software Foundation, Inc.
      Written by James Clark (jjc@jclark.com)
 
 This file is part of groff.
@@ -18,13 +19,13 @@ You should have received a copy of the GNU General Public License along
 with groff; see the file COPYING.  If not, write to the Free Software
 Foundation, 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA. */
 
+#include "lib.h"
+
 #include <stdlib.h>
-#include <string.h>
 #include <assert.h>
 #include <errno.h>
 
 #include "posix.h"
-#include "lib.h"
 #include "errarg.h"
 #include "error.h"
 #include "nonposix.h"
