@@ -394,7 +394,7 @@ void environment::space_newline()
     width_total += x;
     return;
   }
-  add_node(new word_space_node(x, w));
+  add_node(new word_space_node(x, get_fill_color(), w));
   possibly_break_line(0, spread_flag);
   spread_flag = 0;
 }
@@ -428,6 +428,7 @@ void environment::space(hunits space_width, hunits sentence_space_width)
     return;
   }
   add_node(new word_space_node(x,
+			       get_fill_color(),
 			       new width_list(space_width,
 					      sentence_space_width)));
   possibly_break_line(0, spread_flag);
@@ -543,7 +544,7 @@ color *environment::get_prev_glyph_color()
 
 color *environment::get_glyph_color()
 {
-  return cur_glyph_color;
+  return glyph_color;
 }
 
 color *environment::get_prev_fill_color()
@@ -553,23 +554,23 @@ color *environment::get_prev_fill_color()
 
 color *environment::get_fill_color()
 {
-  return cur_fill_color;
+  return fill_color;
 }
 
 void environment::set_glyph_color(color *c)
 {
   if (interrupted)
     return;
-  curenv->prev_glyph_color = curenv->prev_glyph_color;
-  curenv->cur_glyph_color = c;
+  curenv->prev_glyph_color = curenv->glyph_color;
+  curenv->glyph_color = c;
 }
 
 void environment::set_fill_color(color *c)
 {
   if (interrupted)
     return;
-  curenv->prev_fill_color = curenv->prev_fill_color;
-  curenv->cur_fill_color = c;
+  curenv->prev_fill_color = curenv->fill_color;
+  curenv->fill_color = c;
 }
 
 environment::environment(symbol nm)
@@ -640,9 +641,9 @@ environment::environment(symbol nm)
 #endif /* WIDOW_CONTROL */
   ignore_next_eol(0),
   emitted_node(0),
-  cur_glyph_color(&default_color),
+  glyph_color(&default_color),
   prev_glyph_color(&default_color),
-  cur_fill_color(&default_color),
+  fill_color(&default_color),
   prev_fill_color(&default_color),
   name(nm),
   control_char('.'),
@@ -730,9 +731,9 @@ environment::environment(const environment *e)
 #endif /* WIDOW_CONTROL */
   ignore_next_eol(0),
   emitted_node(0),
-  cur_glyph_color(e->cur_glyph_color),
+  glyph_color(e->glyph_color),
   prev_glyph_color(e->prev_glyph_color),
-  cur_fill_color(e->cur_fill_color),
+  fill_color(e->fill_color),
   prev_fill_color(e->prev_fill_color),
   name(e->name),		// so that eg `.if "\n[.ev]"0"' works
   control_char(e->control_char),
@@ -817,9 +818,9 @@ void environment::copy(const environment *e)
   composite = 0;
   ignore_next_eol = e->ignore_next_eol;
   emitted_node = e->emitted_node;
-  cur_glyph_color= e->cur_glyph_color;
+  glyph_color= e->glyph_color;
   prev_glyph_color = e->prev_glyph_color;
-  cur_fill_color = e->cur_fill_color;
+  fill_color = e->fill_color;
   prev_fill_color = e->prev_fill_color;
 }
 
@@ -1383,7 +1384,8 @@ void indent()
   curenv->have_temporary_indent = 0;
   curenv->prev_indent = curenv->indent;
   curenv->indent = temp;
-  curenv->add_html_tag(1, ".in", temp.to_units());
+  if (break_flag)
+    curenv->add_html_tag(1, ".in", temp.to_units());
   tok.next();
 }
 
@@ -1709,7 +1711,7 @@ void environment::output_line(node *n, hunits width)
   if (margin_character_flags) {
     hunits d = line_length + margin_character_distance - saved_indent - width;
     if (d > 0) {
-      n = new hmotion_node(d, n);
+      n = new hmotion_node(d, get_fill_color(), n);
       width += d;
     }
     margin_character_flags &= ~MARGIN_CHARACTER_NEXT;
@@ -1732,7 +1734,7 @@ void environment::output_line(node *n, hunits width)
     n = tem;
   }
   if (!saved_indent.is_zero())
-    nn = new hmotion_node(saved_indent, nn);
+    nn = new hmotion_node(saved_indent, get_fill_color(), nn);
   width += saved_indent;
   if (no_number_count > 0)
     --no_number_count;
@@ -1740,11 +1742,11 @@ void environment::output_line(node *n, hunits width)
     hunits w = (line_number_digit_width
 		*(3+line_number_indent+number_text_separation));
     if (next_line_number % line_number_multiple != 0)
-      nn = new hmotion_node(w, nn);
+      nn = new hmotion_node(w, get_fill_color(), nn);
     else {
       hunits x = w;
-      nn = new hmotion_node(number_text_separation*line_number_digit_width,
-			    nn);
+      nn = new hmotion_node(number_text_separation * line_number_digit_width,
+			    get_fill_color(), nn);
       x -= number_text_separation*line_number_digit_width;
       char buf[30];
       sprintf(buf, "%3d", next_line_number);
@@ -1757,7 +1759,7 @@ void environment::output_line(node *n, hunits width)
 	gn->next = nn;
 	nn = gn;
       }
-      nn = new hmotion_node(x, nn);
+      nn = new hmotion_node(x, get_fill_color(), nn);
     }
     width += w;
     ++next_line_number;
@@ -2285,7 +2287,8 @@ void environment::do_break(int spread)
   if (current_tab)
     wrap_up_tab();
   if (line) {
-    line = new space_node(H0, line); // this is so that hyphenation works
+    // this is so that hyphenation works
+    line = new space_node(H0, get_fill_color(), line);
     space_total++;
     possibly_break_line(0, spread);
   }
@@ -2369,6 +2372,10 @@ void title()
   curenv->char_slant = env.char_slant;
   curenv->fontno = env.fontno;
   curenv->prev_fontno = env.prev_fontno;
+  curenv->glyph_color = env.glyph_color;
+  curenv->prev_glyph_color = env.prev_glyph_color;
+  curenv->fill_color = env.fill_color;
+  curenv->prev_fill_color = env.prev_fill_color;
   node *n = 0;
   node *p = part[2];
   while (p != 0) {
@@ -2380,7 +2387,7 @@ void title()
   hunits title_length(curenv->title_length);
   hunits f = title_length - part_width[1];
   hunits f2 = f/2;
-  n = new hmotion_node(f2 - part_width[2], n);
+  n = new hmotion_node(f2 - part_width[2], curenv->get_fill_color(), n);
   p = part[1];
   while (p != 0) {
     node *tem = p;
@@ -2388,7 +2395,7 @@ void title()
     tem->next = n;
     n = tem;
   }
-  n = new hmotion_node(f - f2 - part_width[0], n);
+  n = new hmotion_node(f - f2 - part_width[0], curenv->get_fill_color(), n);
   p = part[0];
   while (p != 0) {
     node *tem = p;
@@ -2854,7 +2861,7 @@ node *environment::make_tab_node(hunits d, node *next)
     leader_node = 0;
   }
   if (!leader_node)
-    return new hmotion_node(d, 1, 0, next);
+    return new hmotion_node(d, 1, 0, get_fill_color(), next);
   node *n = new hline_node(d, leader_node, next);
   leader_node = 0;
   return n;
@@ -2966,13 +2973,13 @@ void environment::wrap_up_field()
 void environment::add_padding()
 {
   if (current_tab) {
-    tab_contents = new space_node(H0, tab_contents);
+    tab_contents = new space_node(H0, get_fill_color(), tab_contents);
     tab_field_spaces++;
   }
   else {
     if (line == 0)
       start_line();
-    line = new space_node(H0, line);
+    line = new space_node(H0, get_fill_color(), line);
     field_spaces++;
   }
 }
